==> haskell-aeson-yaml-1.1.0.1-279-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-FFiNuM6ZbaZHE1Hqr793N5
key:                  aeson-yaml-1.1.0.1-FFiNuM6ZbaZHE1Hqr793N5
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  b4a920313cbe90e829343dee15f45782
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-FFiNuM6ZbaZHE1Hqr793N5
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-yaml-1.1.0.1-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-GEHgm7jNiAV12Z0qzzp2dr
key:                  aeson-yaml-1.1.0.1-GEHgm7jNiAV12Z0qzzp2dr
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  a69e65714be3556a7d1d2a1c55ca9321
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-GEHgm7jNiAV12Z0qzzp2dr
depends:
    aeson-2.1.2.1-nFo3VMHABFBaVDPPKfnuT base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
